Documentation
¶
Overview ¶
Package endpoint resolves public Drupal service endpoints from sitectl ingress route catalogs.
Index ¶
Constants ¶
const ( ResolutionTraefik = plugin.IngressRouteResolutionTraefik ResolutionCatalog = plugin.IngressRouteResolutionCatalog )
const (
// JSONAPIRoute is Drupal's public JSON:API endpoint route name.
JSONAPIRoute = "jsonapi"
)
Variables ¶
This section is empty.
Functions ¶
func Provider ¶
func Provider() plugin.IngressRouteProvider
Provider returns the Drupal ingress route provider shared by route discovery and JSON:API endpoint resolution.
Types ¶
type Resolution ¶
type Resolution = plugin.IngressRouteResolution
Resolution identifies the route source selected for an endpoint.
Click to show internal directories.
Click to hide internal directories.